##  Activating the API
To use the AI Agent API, you need to activate it first. This gives you access to an API endpoint for uploading AI agent cards. If needed, you can deactivate the API. To learn how to do this, see [Deactivating the API](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api?locale=en-US&state=PRODUCTION&version=CLOUD#loio1470a6a3f7d346bcaaecf1f0e8fcc04f__Deactivating-the-API).
To activate the AI Agent API, follow these steps:
  1. Go to the Integrations section in the administration area.
  2. Choose Add Integration.
  3. Under AI Agent Discovery, choose Configure for AI Agent API.
  4. Preview the changes that will apply to your workspace. By activating the API, you also activate the AI agent extension to the meta model. To learn more about this extension, see [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.").
  5. Choose Enable.
